@@ -14,6 +14,7 @@
 package main
 
 import (
+	"errors"
 	"fmt"
 	"html"
 	"net"
@@ -28,12 +29,12 @@ import (
 	"syscall"
 
 	"github.com/alecthomas/kingpin/v2"
-	"github.com/go-kit/log/level"
-	"github.com/pkg/errors"
 	"github.com/prometheus/client_golang/prometheus"
+	versioncollector "github.com/prometheus/client_golang/prometheus/collectors/version"
+	"github.com/prometheus/client_golang/prometheus/promauto"
 	"github.com/prometheus/client_golang/prometheus/promhttp"
-	"github.com/prometheus/common/promlog"
-	"github.com/prometheus/common/promlog/flag"
+	"github.com/prometheus/common/promslog"
+	"github.com/prometheus/common/promslog/flag"
 	"github.com/prometheus/common/version"
 	"github.com/prometheus/exporter-toolkit/web"
 	webflag "github.com/prometheus/exporter-toolkit/web/kingpinflag"
@@ -44,21 +45,25 @@ import (
 )
 
 var (
-	sc = &config.SafeConfig{
-		C: &config.Config{},
-	}
+	sc = config.NewSafeConfig(prometheus.DefaultRegisterer)
 
-	configFile    = kingpin.Flag("config.file", "Blackbox exporter configuration file.").Default("blackbox.yml").String()
-	timeoutOffset = kingpin.Flag("timeout-offset", "Offset to subtract from timeout in seconds.").Default("0.5").Float64()
-	configCheck   = kingpin.Flag("config.check", "If true validate the config file and then exit.").Default().Bool()
-	historyLimit  = kingpin.Flag("history.limit", "The maximum amount of items to keep in the history.").Default("100").Uint()
-	externalURL   = kingpin.Flag("web.external-url", "The URL under which Blackbox exporter is externally reachable (for example, if Blackbox exporter is served via a reverse proxy). Used for generating relative and absolute links back to Blackbox exporter itself. If the URL has a path portion, it will be used to prefix all HTTP endpoints served by Blackbox exporter. If omitted, relevant URL components will be derived automatically.").PlaceHolder("<url>").String()
-	routePrefix   = kingpin.Flag("web.route-prefix", "Prefix for the internal routes of web endpoints. Defaults to path of --web.external-url.").PlaceHolder("<path>").String()
-	toolkitFlags  = webflag.AddFlags(kingpin.CommandLine, ":9115")
+	configFile     = kingpin.Flag("config.file", "Blackbox exporter configuration file.").Default("blackbox.yml").String()
+	timeoutOffset  = kingpin.Flag("timeout-offset", "Offset to subtract from timeout in seconds.").Default("0.5").Float64()
+	configCheck    = kingpin.Flag("config.check", "If true validate the config file and then exit.").Default().Bool()
+	logLevelProber = kingpin.Flag("log.prober", "Log level from probe requests. One of: [debug, info, warn, error]").Default("info").String()
+	historyLimit   = kingpin.Flag("history.limit", "The maximum amount of items to keep in the history.").Default("100").Uint()
+	externalURL    = kingpin.Flag("web.external-url", "The URL under which Blackbox exporter is externally reachable (for example, if Blackbox exporter is served via a reverse proxy). Used for generating relative and absolute links back to Blackbox exporter itself. If the URL has a path portion, it will be used to prefix all HTTP endpoints served by Blackbox exporter. If omitted, relevant URL components will be derived automatically.").PlaceHolder("<url>").String()
+	routePrefix    = kingpin.Flag("web.route-prefix", "Prefix for the internal routes of web endpoints. Defaults to path of --web.external-url.").PlaceHolder("<path>").String()
+	toolkitFlags   = webflag.AddFlags(kingpin.CommandLine, ":9115")
+
+	moduleUnknownCounter = promauto.NewCounter(prometheus.CounterOpts{
+		Name: "blackbox_module_unknown_total",
+		Help: "Count of unknown modules requested by probes",
+	})
 )
 
 func init() {
-	prometheus.MustRegister(version.NewCollector("blackbox_exporter"))
+	prometheus.MustRegister(versioncollector.NewCollector("blackbox_exporter"))
 }
 
 func main() {
@@ -67,43 +72,46 @@ func main() {
 
 func run() int {
 	kingpin.CommandLine.UsageWriter(os.Stdout)
-	promlogConfig := &promlog.Config{}
-	flag.AddFlags(kingpin.CommandLine, promlogConfig)
+	promslogConfig := &promslog.Config{}
+	flag.AddFlags(kingpin.CommandLine, promslogConfig)
 	kingpin.Version(version.Print("blackbox_exporter"))
 	kingpin.HelpFlag.Short('h')
 	kingpin.Parse()
-	logger := promlog.New(promlogConfig)
+	logger := promslog.New(promslogConfig)
 	rh := &prober.ResultHistory{MaxResults: *historyLimit}
 
-	level.Info(logger).Log("msg", "Starting blackbox_exporter", "version", version.Info())
-	level.Info(logger).Log("build_context", version.BuildContext())
+	allowedLevel := &promslog.AllowedLevel{}
+	_ = allowedLevel.Set(*logLevelProber)
+
+	logger.Info("Starting blackbox_exporter", "version", version.Info())
+	logger.Info(version.BuildContext())
 
 	if err := sc.ReloadConfig(*configFile, logger); err != nil {
-		level.Error(logger).Log("msg", "Error loading config", "err", err)
+		logger.Error("Error loading config", "err", err)
 		return 1
 	}
 
 	if *configCheck {
-		level.Info(logger).Log("msg", "Config file is ok exiting...")
+		logger.Info("Config file is ok exiting...")
 		return 0
 	}
 
-	level.Info(logger).Log("msg", "Loaded config file")
+	logger.Info("Loaded config file")
 
 	// Infer or set Blackbox exporter externalURL
 	listenAddrs := toolkitFlags.WebListenAddresses
 	if *externalURL == "" && *toolkitFlags.WebSystemdSocket {
-		level.Error(logger).Log("msg", "Cannot automatically infer external URL with systemd socket listener. Please provide --web.external-url")
+		logger.Error("Cannot automatically infer external URL with systemd socket listener. Please provide --web.external-url")
 		return 1
 	} else if *externalURL == "" && len(*listenAddrs) > 1 {
-		level.Info(logger).Log("msg", "Inferring external URL from first provided listen address")
+		logger.Info("Inferring external URL from first provided listen address")
 	}
 	beURL, err := computeExternalURL(*externalURL, (*listenAddrs)[0])
 	if err != nil {
-		level.Error(logger).Log("msg", "failed to determine external URL", "err", err)
+		logger.Error("failed to determine external URL", "err", err)
 		return 1
 	}
-	level.Debug(logger).Log("externalURL", beURL.String())
+	logger.Debug(beURL.String())
 
 	// Default -web.route-prefix to path of -web.external-url.
 	if *routePrefix == "" {
@@ -117,7 +125,7 @@ func run() int {
 	if *routePrefix != "/" {
 		*routePrefix = *routePrefix + "/"
 	}
-	level.Debug(logger).Log("routePrefix", *routePrefix)
+	logger.Debug(*routePrefix)
 
 	hup := make(chan os.Signal, 1)
 	reloadCh := make(chan chan error)
@@ -127,16 +135,16 @@ func run() int {
 			select {
 			case <-hup:
 				if err := sc.ReloadConfig(*configFile, logger); err != nil {
-					level.Error(logger).Log("msg", "Error reloading config", "err", err)
+					logger.Error("Error reloading config", "err", err)
 					continue
 				}
-				level.Info(logger).Log("msg", "Reloaded config file")
+				logger.Info("Reloaded config file")
 			case rc := <-reloadCh:
 				if err := sc.ReloadConfig(*configFile, logger); err != nil {
-					level.Error(logger).Log("msg", "Error reloading config", "err", err)
+					logger.Error("Error reloading config", "err", err)
 					rc <- err
 				} else {
-					level.Info(logger).Log("msg", "Reloaded config file")
+					logger.Info("Reloaded config file")
 					rc <- nil
 				}
 			}
@@ -178,7 +186,7 @@ func run() int {
 		sc.Lock()
 		conf := sc.C
 		sc.Unlock()
-		prober.Handler(w, r, conf, logger, rh, *timeoutOffset, nil)
+		prober.Handler(w, r, conf, logger, rh, *timeoutOffset, nil, moduleUnknownCounter, allowedLevel)
 	})
 	http.HandleFunc(*routePrefix, func(w http.ResponseWriter, r *http.Request) {
 		w.Header().Set("Content-Type", "text/html")
@@ -212,14 +220,32 @@ func run() int {
 	http.HandleFunc(path.Join(*routePrefix, "/logs"), func(w http.ResponseWriter, r *http.Request) {
 		id, err := strconv.ParseInt(r.URL.Query().Get("id"), 10, 64)
 		if err != nil {
-			http.Error(w, "Invalid probe id", 500)
+			id = -1
+		}
+		target := r.URL.Query().Get("target")
+		if err == nil && target != "" {
+			http.Error(w, "Probe id and target can't be defined at the same time", http.StatusBadRequest)
 			return
 		}
-		result := rh.Get(id)
-		if result == nil {
-			http.Error(w, "Probe id not found", 404)
+		if id == -1 && target == "" {
+			http.Error(w, "Probe id or target must be defined as http query parameters", http.StatusBadRequest)
 			return
 		}
+		result := new(prober.Result)
+		if target != "" {
+			result = rh.GetByTarget(target)
+			if result == nil {
+				http.Error(w, "Probe target not found", http.StatusNotFound)
+				return
+			}
+		} else {
+			result = rh.GetById(id)
+			if result == nil {
+				http.Error(w, "Probe id not found", http.StatusNotFound)
+				return
+			}
+		}
+
 		w.Header().Set("Content-Type", "text/plain")
 		w.Write([]byte(result.DebugOutput))
 	})
@@ -229,8 +255,8 @@ func run() int {
 		c, err := yaml.Marshal(sc.C)
 		sc.RUnlock()
 		if err != nil {
-			level.Warn(logger).Log("msg", "Error marshalling configuration", "err", err)
-			http.Error(w, err.Error(), 500)
+			logger.Warn("Error marshalling configuration", "err", err)
+			http.Error(w, err.Error(), http.StatusInternalServerError)
 			return
 		}
 		w.Header().Set("Content-Type", "text/plain")
@@ -244,7 +270,7 @@ func run() int {
 
 	go func() {
 		if err := web.ListenAndServe(srv, toolkitFlags, logger); err != nil {
-			level.Error(logger).Log("msg", "Error starting HTTP server", "err", err)
+			logger.Error("Error starting HTTP server", "err", err)
 			close(srvc)
 		}
 	}()
@@ -252,7 +278,7 @@ func run() int {
 	for {
 		select {
 		case <-term:
-			level.Info(logger).Log("msg", "Received SIGTERM, exiting gracefully...")
+			logger.Info("Received SIGTERM, exiting gracefully...")
 			return 0
 		case <-srvc:
 			return 1
