@@ -22,6 +22,9 @@ import (
 	"crypto/x509"
 	"encoding/pem"
 	"fmt"
+	"io"
+	"log/slog"
+	"net"
 	"net/http"
 	"net/http/httptest"
 	"net/textproto"
@@ -33,9 +36,9 @@ import (
 	"time"
 
 	"github.com/andybalholm/brotli"
-	"github.com/go-kit/log"
 	"github.com/prometheus/client_golang/prometheus"
 	pconfig "github.com/prometheus/common/config"
+	"github.com/prometheus/common/promslog"
 
 	"github.com/prometheus/blackbox_exporter/config"
 )
@@ -67,7 +70,7 @@ func TestHTTPStatusCodes(t *testing.T) {
 		testCTX, cancel := context.WithTimeout(context.Background(), 10*time.Second)
 		defer cancel()
 		result := ProbeHTTP(testCTX, ts.URL,
-			config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, ValidStatusCodes: test.ValidStatusCodes}}, registry, log.NewNopLogger())
+			config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, ValidStatusCodes: test.ValidStatusCodes}}, registry, promslog.NewNopLogger())
 		body := recorder.Body.String()
 		if result != test.ShouldSucceed {
 			t.Fatalf("Test %d had unexpected result: %s", i, body)
@@ -95,7 +98,7 @@ func TestValidHTTPVersion(t *testing.T) {
 			config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{
 				IPProtocolFallback: true,
 				ValidHTTPVersions:  test.ValidHTTPVersions,
-			}}, registry, log.NewNopLogger())
+			}}, registry, promslog.NewNopLogger())
 		body := recorder.Body.String()
 		if result != test.ShouldSucceed {
 			t.Fatalf("Test %v had unexpected result: %s", i, body)
@@ -172,7 +175,7 @@ func TestContentLength(t *testing.T) {
 			fw.Close()
 			return testdata{
 				msg:                    msg,
-				contentLength:          len(buf.Bytes()), // Content lenght is the length of the compressed buffer.
+				contentLength:          len(buf.Bytes()), // Content length is the length of the compressed buffer.
 				uncompressedBodyLength: len(buf.Bytes()), // No decompression.
 				handler: func(w http.ResponseWriter, r *http.Request) {
 					w.Header().Add("Content-Encoding", "br")
@@ -192,7 +195,7 @@ func TestContentLength(t *testing.T) {
 			fw.Close()
 			return testdata{
 				msg:                    msg,
-				contentLength:          len(buf.Bytes()), // Content lenght is the length of the compressed buffer.
+				contentLength:          len(buf.Bytes()), // Content length is the length of the compressed buffer.
 				uncompressedBodyLength: len(buf.Bytes()), // No decompression.
 				handler: func(w http.ResponseWriter, r *http.Request) {
 					w.Header().Add("Content-Encoding", "deflate")
@@ -211,7 +214,7 @@ func TestContentLength(t *testing.T) {
 			gw.Close()
 			return testdata{
 				msg:                    msg,
-				contentLength:          len(buf.Bytes()), // Content lenght is the length of the compressed buffer.
+				contentLength:          len(buf.Bytes()), // Content length is the length of the compressed buffer.
 				uncompressedBodyLength: len(buf.Bytes()), // No decompression.
 				handler: func(w http.ResponseWriter, r *http.Request) {
 					w.Header().Add("Content-Encoding", "gzip")
@@ -239,7 +242,7 @@ func TestContentLength(t *testing.T) {
 					HTTP:    config.HTTPProbe{IPProtocolFallback: true},
 				},
 				registry,
-				log.NewLogfmtLogger(&logbuf))
+				promslog.New(&promslog.Config{Writer: &logbuf}))
 			if !tc.expectFailure && !result {
 				t.Fatalf("probe failed unexpectedly: %s", logbuf.String())
 			} else if tc.expectFailure && result {
@@ -283,7 +286,7 @@ func TestHandlingOfCompressionSetting(t *testing.T) {
 			enc.Write(msg)
 			enc.Close()
 			return testdata{
-				contentLength:          buf.Len(), // Content lenght is the length of the compressed buffer.
+				contentLength:          buf.Len(), // Content length is the length of the compressed buffer.
 				uncompressedBodyLength: len(msg),
 				handler: func(w http.ResponseWriter, r *http.Request) {
 					w.Header().Add("Content-Encoding", "gzip")
@@ -304,7 +307,7 @@ func TestHandlingOfCompressionSetting(t *testing.T) {
 			enc.Write(msg)
 			enc.Close()
 			return testdata{
-				contentLength:          len(buf.Bytes()), // Content lenght is the length of the compressed buffer.
+				contentLength:          len(buf.Bytes()), // Content length is the length of the compressed buffer.
 				uncompressedBodyLength: len(msg),
 				handler: func(w http.ResponseWriter, r *http.Request) {
 					w.Header().Add("Content-Encoding", "br")
@@ -326,7 +329,7 @@ func TestHandlingOfCompressionSetting(t *testing.T) {
 			enc.Write(msg)
 			enc.Close()
 			return testdata{
-				contentLength:          len(buf.Bytes()), // Content lenght is the length of the compressed buffer.
+				contentLength:          len(buf.Bytes()), // Content length is the length of the compressed buffer.
 				uncompressedBodyLength: len(msg),
 				handler: func(w http.ResponseWriter, r *http.Request) {
 					w.Header().Add("Content-Encoding", "deflate")
@@ -365,7 +368,7 @@ func TestHandlingOfCompressionSetting(t *testing.T) {
 			enc.Close()
 			return testdata{
 				expectFailure:          true,
-				contentLength:          buf.Len(), // Content lenght is the length of the compressed buffer.
+				contentLength:          buf.Len(), // Content length is the length of the compressed buffer.
 				uncompressedBodyLength: 0,
 				handler: func(w http.ResponseWriter, r *http.Request) {
 					w.Header().Add("Content-Encoding", "gzip")
@@ -387,7 +390,7 @@ func TestHandlingOfCompressionSetting(t *testing.T) {
 			enc.Close()
 			return testdata{
 				expectFailure:          false,
-				contentLength:          buf.Len(), // Content lenght is the length of the compressed buffer.
+				contentLength:          buf.Len(), // Content length is the length of the compressed buffer.
 				uncompressedBodyLength: len(msg),
 				handler: func(w http.ResponseWriter, r *http.Request) {
 					w.Header().Add("Content-Encoding", "gzip")
@@ -412,7 +415,7 @@ func TestHandlingOfCompressionSetting(t *testing.T) {
 			enc.Close()
 			return testdata{
 				expectFailure:          false,
-				contentLength:          buf.Len(), // Content lenght is the length of the compressed buffer.
+				contentLength:          buf.Len(), // Content length is the length of the compressed buffer.
 				uncompressedBodyLength: len(msg),
 				handler: func(w http.ResponseWriter, r *http.Request) {
 					w.Header().Add("Content-Encoding", "gzip")
@@ -437,7 +440,7 @@ func TestHandlingOfCompressionSetting(t *testing.T) {
 			enc.Close()
 			return testdata{
 				expectFailure:          false,
-				contentLength:          buf.Len(), // Content lenght is the length of the compressed buffer.
+				contentLength:          buf.Len(), // Content length is the length of the compressed buffer.
 				uncompressedBodyLength: len(msg),
 				handler: func(w http.ResponseWriter, r *http.Request) {
 					w.Header().Add("Content-Encoding", "gzip")
@@ -493,7 +496,7 @@ func TestHandlingOfCompressionSetting(t *testing.T) {
 					HTTP:    tc.httpConfig,
 				},
 				registry,
-				log.NewLogfmtLogger(&logbuf))
+				promslog.New(&promslog.Config{Writer: &logbuf}))
 			if !tc.expectFailure && !result {
 				t.Fatalf("probe failed unexpectedly: %s", logbuf.String())
 			} else if tc.expectFailure && result {
@@ -614,7 +617,7 @@ func TestMaxResponseLength(t *testing.T) {
 					},
 				},
 				registry,
-				log.NewNopLogger(),
+				promslog.NewNopLogger(),
 			)
 
 			switch {
@@ -647,7 +650,7 @@ func TestRedirectFollowed(t *testing.T) {
 	registry := prometheus.NewRegistry()
 	testCTX, cancel := context.WithTimeout(context.Background(), 10*time.Second)
 	defer cancel()
-	result := ProbeHTTP(testCTX, ts.URL, config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, HTTPClientConfig: pconfig.DefaultHTTPClientConfig}}, registry, log.NewNopLogger())
+	result := ProbeHTTP(testCTX, ts.URL, config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, HTTPClientConfig: pconfig.DefaultHTTPClientConfig}}, registry, promslog.NewNopLogger())
 	body := recorder.Body.String()
 	if !result {
 		t.Fatalf("Redirect test failed unexpectedly, got %s", body)
@@ -675,7 +678,7 @@ func TestRedirectNotFollowed(t *testing.T) {
 	testCTX, cancel := context.WithTimeout(context.Background(), 10*time.Second)
 	defer cancel()
 	result := ProbeHTTP(testCTX, ts.URL,
-		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, HTTPClientConfig: pconfig.HTTPClientConfig{FollowRedirects: false}, ValidStatusCodes: []int{302}}}, registry, log.NewNopLogger())
+		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, HTTPClientConfig: pconfig.HTTPClientConfig{FollowRedirects: false}, ValidStatusCodes: []int{302}}}, registry, promslog.NewNopLogger())
 	body := recorder.Body.String()
 	if !result {
 		t.Fatalf("Redirect test failed unexpectedly, got %s", body)
@@ -724,9 +727,9 @@ func TestRedirectionLimit(t *testing.T) {
 		ts.URL,
 		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, HTTPClientConfig: pconfig.DefaultHTTPClientConfig}},
 		registry,
-		log.NewNopLogger())
+		promslog.NewNopLogger())
 	if result {
-		t.Fatalf("Probe suceeded unexpectedly")
+		t.Fatalf("Probe succeeded unexpectedly")
 	}
 
 	if tooManyRedirects {
@@ -758,7 +761,7 @@ func TestPost(t *testing.T) {
 	testCTX, cancel := context.WithTimeout(context.Background(), 10*time.Second)
 	defer cancel()
 	result := ProbeHTTP(testCTX, ts.URL,
-		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, Method: "POST"}}, registry, log.NewNopLogger())
+		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, Method: "POST"}}, registry, promslog.NewNopLogger())
 	body := recorder.Body.String()
 	if !result {
 		t.Fatalf("Post test failed unexpectedly, got %s", body)
@@ -781,7 +784,7 @@ func TestBasicAuth(t *testing.T) {
 				TLSConfig: pconfig.TLSConfig{InsecureSkipVerify: false},
 				BasicAuth: &pconfig.BasicAuth{Username: "username", Password: "password"},
 			},
-		}}, registry, log.NewNopLogger())
+		}}, registry, promslog.NewNopLogger())
 	body := recorder.Body.String()
 	if !result {
 		t.Fatalf("HTTP probe failed, got %s", body)
@@ -803,7 +806,7 @@ func TestBearerToken(t *testing.T) {
 			HTTPClientConfig: pconfig.HTTPClientConfig{
 				BearerToken: pconfig.Secret("mysecret"),
 			},
-		}}, registry, log.NewNopLogger())
+		}}, registry, promslog.NewNopLogger())
 	body := recorder.Body.String()
 	if !result {
 		t.Fatalf("HTTP probe failed, got %s", body)
@@ -820,10 +823,10 @@ func TestFailIfNotSSL(t *testing.T) {
 	testCTX, cancel := context.WithTimeout(context.Background(), 10*time.Second)
 	defer cancel()
 	result := ProbeHTTP(testCTX, ts.URL,
-		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfNotSSL: true}}, registry, log.NewNopLogger())
+		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfNotSSL: true}}, registry, promslog.NewNopLogger())
 	body := recorder.Body.String()
 	if result {
-		t.Fatalf("Fail if not SSL test suceeded unexpectedly, got %s", body)
+		t.Fatalf("Fail if not SSL test succeeded unexpectedly, got %s", body)
 	}
 	mfs, err := registry.Gather()
 	if err != nil {
@@ -835,6 +838,104 @@ func TestFailIfNotSSL(t *testing.T) {
 	checkRegistryResults(expectedResults, mfs, t)
 }
 
+type logRecorder struct {
+	msgs map[string]bool
+	next *slog.Logger
+}
+
+func (lr *logRecorder) Enabled(ctx context.Context, level slog.Level) bool {
+	return lr.next.Enabled(ctx, level)
+}
+
+func (lr *logRecorder) Handle(ctx context.Context, r slog.Record) error {
+	if lr.msgs == nil {
+		lr.msgs = make(map[string]bool)
+	}
+
+	lr.msgs[r.Message] = true
+	return nil
+}
+
+func (lr *logRecorder) WithAttrs(attrs []slog.Attr) slog.Handler {
+	lr.next = slog.New(lr.next.Handler().WithAttrs(attrs))
+	return lr
+}
+
+func (lr *logRecorder) WithGroup(name string) slog.Handler {
+	lr.next = slog.New(lr.next.Handler().WithGroup(name))
+	return lr
+}
+
+func TestFailIfNotSSLLogMsg(t *testing.T) {
+	const (
+		Msg     = "Final request was not over SSL"
+		Timeout = time.Second * 10
+	)
+
+	goodServer := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		w.WriteHeader(http.StatusOK)
+	}))
+	defer goodServer.Close()
+
+	// Create a TCP server that closes the connection without an answer, to simulate failure.
+	listener, err := net.Listen("tcp", "127.0.0.1:0")
+	if err != nil {
+		t.Fatal(err)
+	}
+	defer listener.Close()
+	go func() {
+		for {
+			conn, err := listener.Accept()
+			if err != nil {
+				return
+			}
+			conn.Close()
+		}
+	}()
+	badServerURL := fmt.Sprintf("http://%s/", listener.Addr().String())
+
+	for title, tc := range map[string]struct {
+		Config          config.Module
+		URL             string
+		Success         bool
+		MessageExpected bool
+	}{
+		"SSL expected, message": {
+			Config:          config.Module{HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfNotSSL: true}},
+			URL:             goodServer.URL,
+			Success:         false,
+			MessageExpected: true,
+		},
+		"No SSL expected, no message": {
+			Config:          config.Module{HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfNotSSL: false}},
+			URL:             goodServer.URL,
+			Success:         true,
+			MessageExpected: false,
+		},
+		"SSL expected, no message": {
+			Config:          config.Module{HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfNotSSL: true}},
+			URL:             badServerURL,
+			Success:         false,
+			MessageExpected: false,
+		},
+	} {
+		t.Run(title, func(t *testing.T) {
+			recorder := logRecorder{next: promslog.NewNopLogger()}
+			registry := prometheus.NewRegistry()
+			testCTX, cancel := context.WithTimeout(context.Background(), Timeout)
+			defer cancel()
+
+			result := ProbeHTTP(testCTX, tc.URL, tc.Config, registry, slog.New(&recorder))
+			if result != tc.Success {
+				t.Fatalf("Expected success=%v, got=%v", tc.Success, result)
+			}
+			if seen := recorder.msgs[Msg]; seen != tc.MessageExpected {
+				t.Fatalf("SSL message expected=%v, seen=%v", tc.MessageExpected, seen)
+			}
+		})
+	}
+}
+
 func TestFailIfBodyMatchesRegexp(t *testing.T) {
 	testcases := map[string]struct {
 		respBody       string
@@ -877,7 +978,7 @@ func TestFailIfBodyMatchesRegexp(t *testing.T) {
 			registry := prometheus.NewRegistry()
 			testCTX, cancel := context.WithTimeout(context.Background(), 10*time.Second)
 			defer cancel()
-			result := ProbeHTTP(testCTX, ts.URL, config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfBodyMatchesRegexp: testcase.regexps}}, registry, log.NewNopLogger())
+			result := ProbeHTTP(testCTX, ts.URL, config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfBodyMatchesRegexp: testcase.regexps}}, registry, promslog.NewNopLogger())
 			if testcase.expectedResult && !result {
 				t.Fatalf("Regexp test failed unexpectedly, got %s", recorder.Body.String())
 			} else if !testcase.expectedResult && result {
@@ -914,7 +1015,7 @@ func TestFailIfBodyNotMatchesRegexp(t *testing.T) {
 	testCTX, cancel := context.WithTimeout(context.Background(), 10*time.Second)
 	defer cancel()
 	result := ProbeHTTP(testCTX, ts.URL,
-		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfBodyNotMatchesRegexp: []config.Regexp{config.MustNewRegexp("Download the latest version here")}}}, registry, log.NewNopLogger())
+		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfBodyNotMatchesRegexp: []config.Regexp{config.MustNewRegexp("Download the latest version here")}}}, registry, promslog.NewNopLogger())
 	body := recorder.Body.String()
 	if result {
 		t.Fatalf("Regexp test succeeded unexpectedly, got %s", body)
@@ -928,7 +1029,7 @@ func TestFailIfBodyNotMatchesRegexp(t *testing.T) {
 	recorder = httptest.NewRecorder()
 	registry = prometheus.NewRegistry()
 	result = ProbeHTTP(testCTX, ts.URL,
-		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfBodyNotMatchesRegexp: []config.Regexp{config.MustNewRegexp("Download the latest version here")}}}, registry, log.NewNopLogger())
+		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfBodyNotMatchesRegexp: []config.Regexp{config.MustNewRegexp("Download the latest version here")}}}, registry, promslog.NewNopLogger())
 	body = recorder.Body.String()
 	if !result {
 		t.Fatalf("Regexp test failed unexpectedly, got %s", body)
@@ -944,7 +1045,7 @@ func TestFailIfBodyNotMatchesRegexp(t *testing.T) {
 	recorder = httptest.NewRecorder()
 	registry = prometheus.NewRegistry()
 	result = ProbeHTTP(testCTX, ts.URL,
-		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfBodyNotMatchesRegexp: []config.Regexp{config.MustNewRegexp("Download the latest version here"), config.MustNewRegexp("Copyright 2015")}}}, registry, log.NewNopLogger())
+		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfBodyNotMatchesRegexp: []config.Regexp{config.MustNewRegexp("Download the latest version here"), config.MustNewRegexp("Copyright 2015")}}}, registry, promslog.NewNopLogger())
 	body = recorder.Body.String()
 	if result {
 		t.Fatalf("Regexp test succeeded unexpectedly, got %s", body)
@@ -958,7 +1059,7 @@ func TestFailIfBodyNotMatchesRegexp(t *testing.T) {
 	recorder = httptest.NewRecorder()
 	registry = prometheus.NewRegistry()
 	result = ProbeHTTP(testCTX, ts.URL,
-		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfBodyNotMatchesRegexp: []config.Regexp{config.MustNewRegexp("Download the latest version here"), config.MustNewRegexp("Copyright 2015")}}}, registry, log.NewNopLogger())
+		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfBodyNotMatchesRegexp: []config.Regexp{config.MustNewRegexp("Download the latest version here"), config.MustNewRegexp("Copyright 2015")}}}, registry, promslog.NewNopLogger())
 	body = recorder.Body.String()
 	if !result {
 		t.Fatalf("Regexp test failed unexpectedly, got %s", body)
@@ -993,7 +1094,7 @@ func TestFailIfHeaderMatchesRegexp(t *testing.T) {
 		testCTX, cancel := context.WithTimeout(context.Background(), 10*time.Second)
 		defer cancel()
 
-		result := ProbeHTTP(testCTX, ts.URL, config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfHeaderMatchesRegexp: []config.HeaderMatch{test.Rule}}}, registry, log.NewNopLogger())
+		result := ProbeHTTP(testCTX, ts.URL, config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfHeaderMatchesRegexp: []config.HeaderMatch{test.Rule}}}, registry, promslog.NewNopLogger())
 		if result != test.ShouldSucceed {
 			t.Fatalf("Test %d had unexpected result: succeeded: %t, expected: %+v", i, result, test)
 		}
@@ -1041,7 +1142,7 @@ func TestFailIfHeaderNotMatchesRegexp(t *testing.T) {
 		testCTX, cancel := context.WithTimeout(context.Background(), 10*time.Second)
 		defer cancel()
 
-		result := ProbeHTTP(testCTX, ts.URL, config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfHeaderNotMatchesRegexp: []config.HeaderMatch{test.Rule}}}, registry, log.NewNopLogger())
+		result := ProbeHTTP(testCTX, ts.URL, config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, FailIfHeaderNotMatchesRegexp: []config.HeaderMatch{test.Rule}}}, registry, promslog.NewNopLogger())
 		if result != test.ShouldSucceed {
 			t.Fatalf("Test %d had unexpected result: succeeded: %t, expected: %+v", i, result, test)
 		}
@@ -1089,7 +1190,7 @@ func TestHTTPHeaders(t *testing.T) {
 	result := ProbeHTTP(testCTX, ts.URL, config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{
 		IPProtocolFallback: true,
 		Headers:            headers,
-	}}, registry, log.NewNopLogger())
+	}}, registry, promslog.NewNopLogger())
 	if !result {
 		t.Fatalf("Probe failed unexpectedly.")
 	}
@@ -1110,10 +1211,10 @@ func TestFailIfSelfSignedCA(t *testing.T) {
 			HTTPClientConfig: pconfig.HTTPClientConfig{
 				TLSConfig: pconfig.TLSConfig{InsecureSkipVerify: false},
 			},
-		}}, registry, log.NewNopLogger())
+		}}, registry, promslog.NewNopLogger())
 	body := recorder.Body.String()
 	if result {
-		t.Fatalf("Fail if selfsigned CA test suceeded unexpectedly, got %s", body)
+		t.Fatalf("Fail if selfsigned CA test succeeded unexpectedly, got %s", body)
 	}
 	mfs, err := registry.Gather()
 	if err != nil {
@@ -1140,7 +1241,7 @@ func TestSucceedIfSelfSignedCA(t *testing.T) {
 			HTTPClientConfig: pconfig.HTTPClientConfig{
 				TLSConfig: pconfig.TLSConfig{InsecureSkipVerify: true},
 			},
-		}}, registry, log.NewNopLogger())
+		}}, registry, promslog.NewNopLogger())
 	body := recorder.Body.String()
 	if !result {
 		t.Fatalf("Fail if (not strict) selfsigned CA test fails unexpectedly, got %s", body)
@@ -1170,7 +1271,7 @@ func TestTLSConfigIsIgnoredForPlainHTTP(t *testing.T) {
 			HTTPClientConfig: pconfig.HTTPClientConfig{
 				TLSConfig: pconfig.TLSConfig{InsecureSkipVerify: false},
 			},
-		}}, registry, log.NewNopLogger())
+		}}, registry, promslog.NewNopLogger())
 	body := recorder.Body.String()
 	if !result {
 		t.Fatalf("Fail if InsecureSkipVerify affects simple http fails unexpectedly, got %s", body)
@@ -1237,7 +1338,7 @@ func TestHTTPUsesTargetAsTLSServerName(t *testing.T) {
 	url := strings.Replace(ts.URL, "127.0.0.1", "localhost", -1)
 	url = strings.Replace(url, "[::1]", "localhost", -1)
 
-	result := ProbeHTTP(context.Background(), url, module, registry, log.NewNopLogger())
+	result := ProbeHTTP(context.Background(), url, module, registry, promslog.NewNopLogger())
 	if !result {
 		t.Fatalf("TLS probe failed unexpectedly")
 	}
@@ -1257,7 +1358,7 @@ func TestRedirectToTLSHostWorks(t *testing.T) {
 	testCTX, cancel := context.WithTimeout(context.Background(), 10*time.Second)
 	defer cancel()
 	result := ProbeHTTP(testCTX, ts.URL,
-		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, HTTPClientConfig: pconfig.DefaultHTTPClientConfig}}, registry, log.NewNopLogger())
+		config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, HTTPClientConfig: pconfig.DefaultHTTPClientConfig}}, registry, promslog.NewNopLogger())
 	if !result {
 		t.Fatalf("Redirect test failed unexpectedly")
 	}
@@ -1280,7 +1381,7 @@ func TestHTTPPhases(t *testing.T) {
 		HTTPClientConfig: pconfig.HTTPClientConfig{
 			TLSConfig: pconfig.TLSConfig{InsecureSkipVerify: true},
 		},
-	}}, registry, log.NewNopLogger())
+	}}, registry, promslog.NewNopLogger())
 	body := recorder.Body.String()
 	if !result {
 		t.Fatalf("HTTP Phases test failed unexpectedly, got %s", body)
@@ -1330,7 +1431,7 @@ func TestCookieJar(t *testing.T) {
 	registry := prometheus.NewRegistry()
 	testCTX, cancel := context.WithTimeout(context.Background(), 10*time.Second)
 	defer cancel()
-	result := ProbeHTTP(testCTX, ts.URL, config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, HTTPClientConfig: pconfig.DefaultHTTPClientConfig}}, registry, log.NewNopLogger())
+	result := ProbeHTTP(testCTX, ts.URL, config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, HTTPClientConfig: pconfig.DefaultHTTPClientConfig}}, registry, promslog.NewNopLogger())
 	body := recorder.Body.String()
 	if !result {
 		t.Fatalf("Redirect test failed unexpectedly, got %s", body)
@@ -1351,7 +1452,7 @@ func TestSkipResolvePhase(t *testing.T) {
 		testCTX, cancel := context.WithTimeout(context.Background(), 10*time.Second)
 		defer cancel()
 		result := ProbeHTTP(testCTX, ts.URL,
-			config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, HTTPClientConfig: pconfig.DefaultHTTPClientConfig, SkipResolvePhaseWithProxy: true}}, registry, log.NewNopLogger())
+			config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, HTTPClientConfig: pconfig.DefaultHTTPClientConfig, SkipResolvePhaseWithProxy: true}}, registry, promslog.NewNopLogger())
 		if !result {
 			t.Fatalf("Probe unsuccessful")
 		}
@@ -1380,13 +1481,13 @@ func TestSkipResolvePhase(t *testing.T) {
 		httpCfg := pconfig.DefaultHTTPClientConfig
 		u, err := url.Parse("http://127.0.0.1:3128")
 		if err != nil {
-			t.Fatalf(err.Error())
+			t.Fatal(err.Error())
 		}
 		httpCfg.ProxyURL = pconfig.URL{
 			URL: u,
 		}
 		ProbeHTTP(testCTX, ts.URL,
-			config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, HTTPClientConfig: httpCfg, SkipResolvePhaseWithProxy: true}}, registry, log.NewNopLogger())
+			config.Module{Timeout: time.Second, HTTP: config.HTTPProbe{IPProtocolFallback: true, HTTPClientConfig: httpCfg, SkipResolvePhaseWithProxy: true}}, registry, promslog.NewNopLogger())
 		mfs, err := registry.Gather()
 		if err != nil {
 			t.Fatal(err)
@@ -1405,3 +1506,51 @@ func TestSkipResolvePhase(t *testing.T) {
 		checkMetrics(expectedMetrics, mfs, t)
 	})
 }
+
+func TestBody(t *testing.T) {
+	body := "Test Body"
+	tmpBodyFile, err := os.CreateTemp("", "body.txt")
+	if err != nil {
+		t.Fatalf("Error creating body tempfile: %s", err)
+	}
+	if _, err := tmpBodyFile.Write([]byte(body)); err != nil {
+		t.Fatalf("Error writing body tempfile: %s", err)
+	}
+	if err := tmpBodyFile.Close(); err != nil {
+		t.Fatalf("Error closing body tempfie: %s", err)
+	}
+
+	tests := []config.HTTPProbe{
+		{IPProtocolFallback: true, Body: body},
+		{IPProtocolFallback: true, BodyFile: tmpBodyFile.Name()},
+	}
+
+	for i, test := range tests {
+		ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+			b, err := io.ReadAll(r.Body)
+			if err != nil {
+				t.Fatalf("Body test %d failed unexpectedly.", i)
+			}
+			if string(b) != body {
+				t.Fatalf("Body test %d failed unexpectedly.", i)
+			}
+		}))
+		defer ts.Close()
+
+		registry := prometheus.NewRegistry()
+		testCTX, cancel := context.WithTimeout(context.Background(), 10*time.Second)
+		defer cancel()
+		result := ProbeHTTP(
+			testCTX,
+			ts.URL,
+			config.Module{
+				Timeout: time.Second,
+				HTTP:    test},
+			registry,
+			promslog.NewNopLogger(),
+		)
+		if !result {
+			t.Fatalf("Body test %d failed unexpectedly.", i)
+		}
+	}
+}
